@@ -35,7 +35,9 @@
 #include <QDBusConnectionInterface>
 #include <QDBusReply>
 
-K_PLUGIN_FACTORY(NetworkManagementServiceFactory, registerPlugin<NetworkManagementService>();)
+K_PLUGIN_FACTORY_WITH_JSON(NetworkManagementServiceFactory,
+                           "networkmanagement.json",
+                           registerPlugin<NetworkManagementService>();)
 
 class NetworkManagementServicePrivate
 {
@@ -81,7 +83,7 @@ void NetworkManagementService::init()
 
 void NetworkManagementService::slotRegistered(const QDBusObjectPath &path)
 {
-    if (path.path() == QStringLiteral("/modules/networkmanagement")) {
+    if (path.path() == QLatin1String("/modules/networkmanagement")) {
         Q_EMIT registered();
     }
 }
